@@ -43,12 +43,18 @@ class Distribution(ABC):
             import tarfile
 
             with tarfile.open(archive, 'r:gz') as tf:
-                tf.extractall(directory)  # noqa: S202
+                if sys.version_info[:2] >= (3, 12):
+                    tf.extractall(directory, filter='data')
+                else:
+                    tf.extractall(directory)  # noqa: S202
         elif self.source.endswith('.tar.bz2'):
             import tarfile
 
             with tarfile.open(archive, 'r:bz2') as tf:
-                tf.extractall(directory)  # noqa: S202
+                if sys.version_info[:2] >= (3, 12):
+                    tf.extractall(directory, filter='data')
+                else:
+                    tf.extractall(directory)  # noqa: S202
         elif self.source.endswith('.tar.zst'):
             import tarfile
 
@@ -57,7 +63,10 @@ class Distribution(ABC):
             with open(archive, 'rb') as ifh:
                 dctx = zstandard.ZstdDecompressor()
                 with dctx.stream_reader(ifh) as reader, tarfile.open(mode='r|', fileobj=reader) as tf:
-                    tf.extractall(directory)  # noqa: S202
+                    if sys.version_info[:2] >= (3, 12):
+                        tf.extractall(directory, filter='data')
+                    else:
+                        tf.extractall(directory)  # noqa: S202
         else:
             message = f'Unknown archive type: {archive}'
             raise ValueError(message)
@@ -143,7 +152,7 @@ def get_distribution(name: str, source: str = '', variant: str = '') -> Distribu
         abi = 'gnu' if any(platform.libc_ver()) else 'musl'
 
     if not variant:
-        variant = _get_default_variant(name, system, arch, abi)
+        variant = _get_default_variant(name, system, arch)
 
     key = (system, arch, abi, variant)
 
@@ -169,20 +178,12 @@ def get_compatible_distributions() -> dict[str, Distribution]:
     return distributions
 
 
-def _get_default_variant(name: str, system: str, arch: str, abi: str) -> str:
+def _get_default_variant(name: str, system: str, arch: str) -> str:
     # not PyPy
     if name[0].isdigit():
         # https://gregoryszorc.com/docs/python-build-standalone/main/running.html
         variant = os.environ.get(f'HATCH_PYTHON_VARIANT_{system.upper()}', '').lower()
 
-        if system == 'windows':
-            # Shared versus static
-            if variant:
-                return variant
-
-            if abi == 'msvc':
-                return 'shared'
-
         if system == 'linux' and arch == 'x86_64':
             # Intel-specific optimizations depending on age of release
             if variant:
